syntax = "proto3";

message Args {
  string version = 1;
  string service = 2;
  string method = 3;
  bytes args = 4;
}

message Response {
  int32 code = 1;
  string msg = 2;
  bytes resultJson = 3;
}

service RpcService {
  rpc Invoke (Args) returns (Response) {
  }
}